# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: fintekkers/services/security-service/security_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from fintekkers.requests.security import query_security_request_pb2 as fintekkers_dot_requests_dot_security_dot_query__security__request__pb2
from fintekkers.requests.security import query_security_response_pb2 as fintekkers_dot_requests_dot_security_dot_query__security__response__pb2
from fintekkers.requests.security import create_security_request_pb2 as fintekkers_dot_requests_dot_security_dot_create__security__request__pb2
from fintekkers.requests.security import create_security_response_pb2 as fintekkers_dot_requests_dot_security_dot_create__security__response__pb2
from fintekkers.requests.util.errors import summary_pb2 as fintekkers_dot_requests_dot_util_dot_errors_dot_summary__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;fintekkers/services/security-service/security_service.proto\x12$fintekkers.services.security_service\x1a\x39\x66intekkers/requests/security/query_security_request.proto\x1a:fintekkers/requests/security/query_security_response.proto\x1a:fintekkers/requests/security/create_security_request.proto\x1a;fintekkers/requests/security/create_security_response.proto\x1a-fintekkers/requests/util/errors/summary.proto2\x92\x06\n\x08Security\x12\x85\x01\n\x0e\x43reateOrUpdate\x12\x38.fintekkers.requests.security.CreateSecurityRequestProto\x1a\x39.fintekkers.requests.security.CreateSecurityResponseProto\x12}\n\x08GetByIds\x12\x37.fintekkers.requests.security.QuerySecurityRequestProto\x1a\x38.fintekkers.requests.security.QuerySecurityResponseProto\x12}\n\x06Search\x12\x37.fintekkers.requests.security.QuerySecurityRequestProto\x1a\x38.fintekkers.requests.security.QuerySecurityResponseProto0\x01\x12|\n\x07ListIds\x12\x37.fintekkers.requests.security.QuerySecurityRequestProto\x1a\x38.fintekkers.requests.security.QuerySecurityResponseProto\x12\x81\x01\n\x16ValidateCreateOrUpdate\x12\x38.fintekkers.requests.security.CreateSecurityRequestProto\x1a-.fintekkers.requests.util.errors.SummaryProto\x12~\n\x14ValidateQueryRequest\x12\x37.fintekkers.requests.security.QuerySecurityRequestProto\x1a-.fintekkers.requests.util.errors.SummaryProtoB\x06\x88\x01\x01\x90\x01\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'fintekkers.services.security_service.security_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\210\001\001\220\001\001'
  _SECURITY._serialized_start=389
  _SECURITY._serialized_end=1175
_builder.BuildServices(DESCRIPTOR, 'fintekkers.services.security_service.security_service_pb2', globals())
# @@protoc_insertion_point(module_scope)



from fintekkers.models.transaction import transaction_pb2 as _transaction_pb2
from fintekkers.requests.transaction import query_transaction_request_pb2 as _query_transaction_request_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class QueryTransactionResponseProto(_message.Message):
    __slots__ = ["create_transaction_request", "object_class", "transaction_response", "version"]
    CREATE_TRANSACTION_REQUEST_FIELD_NUMBER: _ClassVar[int]
    OBJECT_CLASS_FIELD_NUMBER: _ClassVar[int]
    TRANSACTION_RESPONSE_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    create_transaction_request: _query_transaction_request_pb2.QueryTransactionRequestProto
    object_class: str
    transaction_response: _containers.RepeatedCompositeFieldContainer[_transaction_pb2.TransactionProto]
    version: str
    def __init__(self, object_class: _Optional[str] = ..., version: _Optional[str] = ..., create_transaction_request: _Optional[_Union[_query_transaction_request_pb2.QueryTransactionRequestProto, _Mapping]] = ..., transaction_response: _Optional[_Iterable[_Union[_transaction_pb2.TransactionProto, _Mapping]]] = ...) -> None: ...



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from fintekkers.requests.portfolio import create_portfolio_request_pb2 as fintekkers_dot_requests_dot_portfolio_dot_create__portfolio__request__pb2
from fintekkers.requests.portfolio import create_portfolio_response_pb2 as fintekkers_dot_requests_dot_portfolio_dot_create__portfolio__response__pb2
from fintekkers.requests.portfolio import query_portfolio_request_pb2 as fintekkers_dot_requests_dot_portfolio_dot_query__portfolio__request__pb2
from fintekkers.requests.portfolio import query_portfolio_response_pb2 as fintekkers_dot_requests_dot_portfolio_dot_query__portfolio__response__pb2
from fintekkers.requests.util.errors import summary_pb2 as fintekkers_dot_requests_dot_util_dot_errors_dot_summary__pb2


class PortfolioStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateOrUpdate = channel.unary_unary(
                '/fintekkers.services.portfolio_service.Portfolio/CreateOrUpdate',
                request_serializer=fintekkers_dot_requests_dot_portfolio_dot_create__portfolio__request__pb2.CreatePortfolioRequestProto.SerializeToString,
                response_deserializer=fintekkers_dot_requests_dot_portfolio_dot_create__portfolio__response__pb2.CreatePortfolioResponseProto.FromString,
                )
        self.GetByIds = channel.unary_unary(
                '/fintekkers.services.portfolio_service.Portfolio/GetByIds',
                request_serializer=fintekkers_dot_requests_dot_portfolio_dot_query__portfolio__request__pb2.QueryPortfolioRequestProto.SerializeToString,
                response_deserializer=fintekkers_dot_requests_dot_portfolio_dot_query__portfolio__response__pb2.QueryPortfolioResponseProto.FromString,
                )
        self.Search = channel.unary_stream(
                '/fintekkers.services.portfolio_service.Portfolio/Search',
                request_serializer=fintekkers_dot_requests_dot_portfolio_dot_query__portfolio__request__pb2.QueryPortfolioRequestProto.SerializeToString,
                response_deserializer=fintekkers_dot_requests_dot_portfolio_dot_query__portfolio__response__pb2.QueryPortfolioResponseProto.FromString,
                )
        self.ListIds = channel.unary_unary(
                '/fintekkers.services.portfolio_service.Portfolio/ListIds',
                request_serializer=fintekkers_dot_requests_dot_portfolio_dot_query__portfolio__request__pb2.QueryPortfolioRequestProto.SerializeToString,
                response_deserializer=fintekkers_dot_requests_dot_portfolio_dot_query__portfolio__response__pb2.QueryPortfolioResponseProto.FromString,
                )
        self.ValidateCreateOrUpdate = channel.unary_unary(
                '/fintekkers.services.portfolio_service.Portfolio/ValidateCreateOrUpdate',
                request_serializer=fintekkers_dot_requests_dot_portfolio_dot_create__portfolio__request__pb2.CreatePortfolioRequestProto.SerializeToString,
                response_deserializer=fintekkers_dot_requests_dot_util_dot_errors_dot_summary__pb2.SummaryProto.FromString,
                )
        self.ValidateQueryRequest = channel.unary_unary(
                '/fintekkers.services.portfolio_service.Portfolio/ValidateQueryRequest',
                request_serializer=fintekkers_dot_requests_dot_portfolio_dot_query__portfolio__request__pb2.QueryPortfolioRequestProto.SerializeToString,
                response_deserializer=fintekkers_dot_requests_dot_util_dot_errors_dot_summary__pb2.SummaryProto.FromString,
                )


class PortfolioServicer(object):
    """Missing associated documentation comment in .proto file."""

    def CreateOrUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetByIds(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Search(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListIds(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ValidateCreateOrUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ValidateQueryRequest(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_PortfolioServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateOrUpdate': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateOrUpdate,
                    request_deserializer=fintekkers_dot_requests_dot_portfolio_dot_create__portfolio__request__pb2.CreatePortfolioRequestProto.FromString,
                    response_serializer=fintekkers_dot_requests_dot_portfolio_dot_create__portfolio__response__pb2.CreatePortfolioResponseProto.SerializeToString,
            ),
            'GetByIds': grpc.unary_unary_rpc_method_handler(
                    servicer.GetByIds,
                    request_deserializer=fintekkers_dot_requests_dot_portfolio_dot_query__portfolio__request__pb2.QueryPortfolioRequestProto.FromString,
                    response_serializer=fintekkers_dot_requests_dot_portfolio_dot_query__portfolio__response__pb2.QueryPortfolioResponseProto.SerializeToString,
            ),
            'Search': grpc.unary_stream_rpc_method_handler(
                    servicer.Search,
                    request_deserializer=fintekkers_dot_requests_dot_portfolio_dot_query__portfolio__request__pb2.QueryPortfolioRequestProto.FromString,
                    response_serializer=fintekkers_dot_requests_dot_portfolio_dot_query__portfolio__response__pb2.QueryPortfolioResponseProto.SerializeToString,
            ),
            'ListIds': grpc.unary_unary_rpc_method_handler(
                    servicer.ListIds,
                    request_deserializer=fintekkers_dot_requests_dot_portfolio_dot_query__portfolio__request__pb2.QueryPortfolioRequestProto.FromString,
                    response_serializer=fintekkers_dot_requests_dot_portfolio_dot_query__portfolio__response__pb2.QueryPortfolioResponseProto.SerializeToString,
            ),
            'ValidateCreateOrUpdate': grpc.unary_unary_rpc_method_handler(
                    servicer.ValidateCreateOrUpdate,
                    request_deserializer=fintekkers_dot_requests_dot_portfolio_dot_create__portfolio__request__pb2.CreatePortfolioRequestProto.FromString,
                    response_serializer=fintekkers_dot_requests_dot_util_dot_errors_dot_summary__pb2.SummaryProto.SerializeToString,
            ),
            'ValidateQueryRequest': grpc.unary_unary_rpc_method_handler(
                    servicer.ValidateQueryRequest,
                    request_deserializer=fintekkers_dot_requests_dot_portfolio_dot_query__portfolio__request__pb2.QueryPortfolioRequestProto.FromString,
                    response_serializer=fintekkers_dot_requests_dot_util_dot_errors_dot_summary__pb2.SummaryProto.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'fintekkers.services.portfolio_service.Portfolio', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Portfolio(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def CreateOrUpdate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/fintekkers.services.portfolio_service.Portfolio/CreateOrUpdate',
            fintekkers_dot_requests_dot_portfolio_dot_create__portfolio__request__pb2.CreatePortfolioRequestProto.SerializeToString,
            fintekkers_dot_requests_dot_portfolio_dot_create__portfolio__response__pb2.CreatePortfolioResponseProto.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetByIds(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/fintekkers.services.portfolio_service.Portfolio/GetByIds',
            fintekkers_dot_requests_dot_portfolio_dot_query__portfolio__request__pb2.QueryPortfolioRequestProto.SerializeToString,
            fintekkers_dot_requests_dot_portfolio_dot_query__portfolio__response__pb2.QueryPortfolioResponseProto.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Search(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/fintekkers.services.portfolio_service.Portfolio/Search',
            fintekkers_dot_requests_dot_portfolio_dot_query__portfolio__request__pb2.QueryPortfolioRequestProto.SerializeToString,
            fintekkers_dot_requests_dot_portfolio_dot_query__portfolio__response__pb2.QueryPortfolioResponseProto.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListIds(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/fintekkers.services.portfolio_service.Portfolio/ListIds',
            fintekkers_dot_requests_dot_portfolio_dot_query__portfolio__request__pb2.QueryPortfolioRequestProto.SerializeToString,
            fintekkers_dot_requests_dot_portfolio_dot_query__portfolio__response__pb2.QueryPortfolioResponseProto.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ValidateCreateOrUpdate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/fintekkers.services.portfolio_service.Portfolio/ValidateCreateOrUpdate',
            fintekkers_dot_requests_dot_portfolio_dot_create__portfolio__request__pb2.CreatePortfolioRequestProto.SerializeToString,
            fintekkers_dot_requests_dot_util_dot_errors_dot_summary__pb2.SummaryProto.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ValidateQueryRequest(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/fintekkers.services.portfolio_service.Portfolio/ValidateQueryRequest',
            fintekkers_dot_requests_dot_portfolio_dot_query__portfolio__request__pb2.QueryPortfolioRequestProto.SerializeToString,
            fintekkers_dot_requests_dot_util_dot_errors_dot_summary__pb2.SummaryProto.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class NodePartition(_message.Message):
    __slots__ = ["namespace", "object_class", "partition", "version"]
    NAMESPACE_FIELD_NUMBER: _ClassVar[int]
    OBJECT_CLASS_FIELD_NUMBER: _ClassVar[int]
    PARTITION_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    namespace: str
    object_class: str
    partition: int
    version: str
    def __init__(self, object_class: _Optional[str] = ..., version: _Optional[str] = ..., partition: _Optional[int] = ..., namespace: _Optional[str] = ...) -> None: ...



from fintekkers.requests.position import query_position_request_pb2 as _query_position_request_pb2
from fintekkers.requests.position import query_position_response_pb2 as _query_position_response_pb2
from fintekkers.requests.util.errors import summary_pb2 as _summary_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import service as _service
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor

class Position(_service.service): ...

class Position_Stub(Position): ...



from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

ADJUSTED_TENOR: FieldProto
ASSET_CLASS: FieldProto
AS_OF: FieldProto
CASH_IMPACT_SECURITY: FieldProto
DESCRIPTOR: _descriptor.FileDescriptor
EFFECTIVE_DATE: FieldProto
ID: FieldProto
IDENTIFIER: FieldProto
ISSUE_DATE: FieldProto
IS_CANCELLED: FieldProto
MATURITY_DATE: FieldProto
PORTFOLIO: FieldProto
PORTFOLIO_ID: FieldProto
PORTFOLIO_NAME: FieldProto
POSITION_STATUS: FieldProto
PRICE: FieldProto
PRICE_ID: FieldProto
PRODUCT_CLASS: FieldProto
PRODUCT_TYPE: FieldProto
SECURITY: FieldProto
SECURITY_DESCRIPTION: FieldProto
SECURITY_ID: FieldProto
SETTLEMENT_DATE: FieldProto
STRATEGY: FieldProto
TAX_LOT_CLOSE_DATE: FieldProto
TAX_LOT_OPEN_DATE: FieldProto
TENOR: FieldProto
TRADE_DATE: FieldProto
TRANSACTION_TYPE: FieldProto
UNKNOWN_FIELD: FieldProto

class FieldProto(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []



from typing import Generator

from grpc import Channel

from fintekkers.models.security.security_pb2 import SecurityProto
from fintekkers.services.security_service.security_service_pb2 import Security_Stub
from fintekkers.services.security_service import  security_service_pb2_grpc

from fintekkers.requests.security.query_security_response_pb2 import QuerySecurityResponseProto
from fintekkers.wrappers.requests.security import QuerySecurityRequest, CreateSecurityRequest

from fintekkers.wrappers.models.util.environment import Environment, SECURITY_SERVICE

class SecurityService(Security_Stub):
    def __init__(self, stub:Security_Stub):
        self.stub = stub

    def Search(self, request:QuerySecurityRequest) -> Generator[SecurityProto, None, None]:
        # print(Environment().IS_RUNNING_LOCALLY)

        # stub:Channel = Environment().get_service_insecure_channel(SECURITY_SERVICE)
        
        # LOCAL_CHANNEL = Environment().get_service_insecure_channel(SECURITY_SERVICE)
        # service = security_service_pb2_grpc.SecurityStub(LOCAL_CHANNEL)
        # results = service.Search(request.proto)

        responses = self.stub.Search(request.proto)

        try:
            while not responses._is_complete():
                response:QuerySecurityResponseProto = responses.next()
                
                for security_proto in response.security_response:
                    yield security_proto
        except StopIteration:
            pass
        except Exception as e:
            print(e)
        
        #This will send the cancel message to the server to kill the connection
        responses.cancel()



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class Endpoint(_message.Message):
    __slots__ = ["fully_qualified_url", "ip", "port"]
    FULLY_QUALIFIED_URL_FIELD_NUMBER: _ClassVar[int]
    IP_FIELD_NUMBER: _ClassVar[int]
    PORT_FIELD_NUMBER: _ClassVar[int]
    fully_qualified_url: str
    ip: str
    port: int
    def __init__(self, ip: _Optional[str] = ..., port: _Optional[int] = ..., fully_qualified_url: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: fintekkers/requests/util/lock/lock_request.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from fintekkers.models.util.lock import node_partition_pb2 as fintekkers_dot_models_dot_util_dot_lock_dot_node__partition__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0fintekkers/requests/util/lock/lock_request.proto\x12\x1d\x66intekkers.requests.util.lock\x1a\x30\x66intekkers/models/util/lock/node_partition.proto\"}\n\x10LockRequestProto\x12\x14\n\x0cobject_class\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x42\n\x0enode_partition\x18\x0b \x01(\x0b\x32*.fintekkers.models.util.lock.NodePartitionB\x15\x42\x11LockRequestProtosP\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'fintekkers.requests.util.lock.lock_request_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'B\021LockRequestProtosP\001'
  _LOCKREQUESTPROTO._serialized_start=133
  _LOCKREQUESTPROTO._serialized_end=258
# @@protoc_insertion_point(module_scope)



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class DecimalValueProto(_message.Message):
    __slots__ = ["arbitrary_precision_value"]
    ARBITRARY_PRECISION_VALUE_FIELD_NUMBER: _ClassVar[int]
    arbitrary_precision_value: str
    def __init__(self, arbitrary_precision_value: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: fintekkers/models/security/coupon_frequency.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1fintekkers/models/security/coupon_frequency.proto\x12\x1a\x66intekkers.models.security*\x7f\n\x14\x43ouponFrequencyProto\x12\x1c\n\x18UNKNOWN_COUPON_FREQUENCY\x10\x00\x12\x0c\n\x08\x41NNUALLY\x10\x01\x12\x10\n\x0cSEMIANNUALLY\x10\x02\x12\r\n\tQUARTERLY\x10\x03\x12\x0b\n\x07MONTHLY\x10\x04\x12\r\n\tNO_COUPON\x10\x05\x42\x19\x42\x15\x43ouponFrequencyProtosP\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'fintekkers.models.security.coupon_frequency_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'B\025CouponFrequencyProtosP\001'
  _COUPONFREQUENCYPROTO._serialized_start=81
  _COUPONFREQUENCYPROTO._serialized_end=208
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: fintekkers/requests/portfolio/query_portfolio_response.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from fintekkers.models.portfolio import portfolio_pb2 as fintekkers_dot_models_dot_portfolio_dot_portfolio__pb2
from fintekkers.requests.portfolio import query_portfolio_request_pb2 as fintekkers_dot_requests_dot_portfolio_dot_query__portfolio__request__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n<fintekkers/requests/portfolio/query_portfolio_response.proto\x12\x1d\x66intekkers.requests.portfolio\x1a+fintekkers/models/portfolio/portfolio.proto\x1a;fintekkers/requests/portfolio/query_portfolio_request.proto\"\xe9\x01\n\x1bQueryPortfolioResponseProto\x12\x14\n\x0cobject_class\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12Z\n\x17query_portfolio_request\x18\x14 \x01(\x0b\x32\x39.fintekkers.requests.portfolio.QueryPortfolioRequestProto\x12G\n\x12portfolio_response\x18\x1e \x03(\x0b\x32+.fintekkers.models.portfolio.PortfolioProtoB B\x1cQueryPortfolioResponseProtosP\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'fintekkers.requests.portfolio.query_portfolio_response_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'B\034QueryPortfolioResponseProtosP\001'
  _QUERYPORTFOLIORESPONSEPROTO._serialized_start=202
  _QUERYPORTFOLIORESPONSEPROTO._serialized_end=435
# @@protoc_insertion_point(module_scope)




from datetime import date, datetime
from uuid import uuid4
from google.protobuf.any_pb2 import Any
from google.protobuf.timestamp_pb2 import Timestamp

from fintekkers.models.position.field_pb2 import FieldProto
from fintekkers.models.position.position_filter_pb2 import PositionFilterProto
from fintekkers.models.position.position_util_pb2 import FieldMapEntry
from fintekkers.models.security.coupon_frequency_pb2 import NO_COUPON, SEMIANNUALLY
from fintekkers.models.security.coupon_type_pb2 import FIXED, FLOAT, ZERO
from fintekkers.models.security.identifier.identifier_pb2 import IdentifierProto
from fintekkers.models.security.identifier.identifier_type_pb2 import CUSIP
from fintekkers.models.security.security_pb2 import SecurityProto
from fintekkers.models.security.security_quantity_type_pb2 import ORIGINAL_FACE_VALUE
from fintekkers.models.security.security_type_pb2 import BOND_SECURITY, FRN, SecurityTypeProto
from fintekkers.models.util.local_timestamp_pb2 import LocalTimestampProto
from fintekkers.models.util.uuid_pb2 import UUIDProto

from fintekkers.requests.security.create_security_request_pb2 import CreateSecurityRequestProto
from fintekkers.requests.security.query_security_request_pb2 import QuerySecurityRequestProto

from fintekkers.wrappers.models.util.date_utils import get_date_proto
from fintekkers.wrappers.models.util.serialization import ProtoSerializationUtil

class CreateSecurityRequest():
    @staticmethod
    def create_ust_security_request(
        cusip:str,
        cash_security:SecurityProto,
        security_type:SecurityTypeProto=SecurityTypeProto.BOND_SECURITY,
        coupon_rate:float=0.0,
        spread:float=0.0,
        face_value:float=0.0,
        issue_date:date=date.today(),
        dated_date:date=date.today(),
        maturity_date:date=date.today(),
    ):
        '''
            Creates a request to create a security representing a US treasury (bills, notes and bonds)

                Parameters:
                        Parameters are already in protos, see type hints

                Returns:
                        request (CreateSecurityRequest): A request wrapper, with the fields attached
        '''
        id = IdentifierProto(identifier_type=CUSIP, identifier_value=cusip)

        security_type = BOND_SECURITY
        coupon_frequency = SEMIANNUALLY
        coupon_type = FIXED

        # if security_type == TIPS: 
        #     security_type = TIPS
        if security_type == FRN:
            # security_type = FRN
            coupon_type = FLOAT
            coupon_rate = spread
        if security_type == ZERO:
            coupon_type = ZERO
            coupon_frequency = NO_COUPON

        issue_date_proto = get_date_proto(issue_date)
        dated_date_proto = get_date_proto(dated_date) if dated_date != None else None
        maturity_date_proto = get_date_proto(maturity_date)

        security_proto:SecurityProto = SecurityProto(
            as_of=LocalTimestampProto(time_zone="America/New_York", timestamp=Timestamp(seconds=1,nanos=0)),
            uuid=UUIDProto(raw_uuid=uuid4().bytes),
            issuer_name="US Government",
            identifier=id,
            issue_date=issue_date_proto,
            dated_date=dated_date_proto,
            maturity_date=maturity_date_proto,
            security_type=security_type,
            quantity_type=ORIGINAL_FACE_VALUE, 
            settlement_currency=cash_security,
            coupon_frequency=coupon_frequency,
            coupon_type=coupon_type,
            coupon_rate=ProtoSerializationUtil.serialize(coupon_rate),
            asset_class="Fixed Income",
            face_value=ProtoSerializationUtil.serialize(face_value),
        )

        proto:CreateSecurityRequestProto = CreateSecurityRequestProto(
            security_input=security_proto
        )

        return CreateSecurityRequest(proto=proto)
    
    def __init__(self, proto:CreateSecurityRequestProto):
        self.proto = proto

class QuerySecurityRequest():
    @staticmethod
    def create_query_request(fields:dict):
        '''
        Returns a query request from a dict of field/values

                Parameters:
                        fields (dict): A dictionary of fields with values

                Returns:
                        request (QuerySecurityRequest): A request wrapper, with the fields attached. It assumes that all filters are an equals operation
        '''

        filters = []

        for field in fields:
            field:FieldProto

            field_value = fields[field]            

            packed_value:Any = Any()
            packed_value.Pack(msg=field_value)

            entry = FieldMapEntry(
                field=field, field_value_packed=packed_value
            )

            filters.append(entry)
        

        as_of_proto:LocalTimestampProto = ProtoSerializationUtil.serialize(datetime.now())

        request:QuerySecurityRequestProto = QuerySecurityRequestProto(
            search_security_input=PositionFilterProto(
                filters=filters
            ),
            as_of=as_of_proto
        )

        return QuerySecurityRequest(proto=request)
    
    def __init__(self, proto:CreateSecurityRequestProto):
        self.proto = proto


from fintekkers.models.util import decimal_value_pb2 as _decimal_value_pb2
from fintekkers.models.util import local_date_pb2 as _local_date_pb2
from fintekkers.models.util import local_timestamp_pb2 as _local_timestamp_pb2
from fintekkers.models.util import uuid_pb2 as _uuid_pb2
from fintekkers.models.security.identifier import identifier_pb2 as _identifier_pb2
from fintekkers.models.security import security_type_pb2 as _security_type_pb2
from fintekkers.models.security import security_quantity_type_pb2 as _security_quantity_type_pb2
from fintekkers.models.security import coupon_frequency_pb2 as _coupon_frequency_pb2
from fintekkers.models.security import coupon_type_pb2 as _coupon_type_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SecurityProto(_message.Message):
    __slots__ = ["as_of", "asset_class", "cash_id", "coupon_frequency", "coupon_rate", "coupon_type", "dated_date", "description", "face_value", "identifier", "is_link", "issue_date", "issuer_name", "maturity_date", "object_class", "quantity_type", "security_type", "settlement_currency", "uuid", "valid_from", "valid_to", "version"]
    ASSET_CLASS_FIELD_NUMBER: _ClassVar[int]
    AS_OF_FIELD_NUMBER: _ClassVar[int]
    CASH_ID_FIELD_NUMBER: _ClassVar[int]
    COUPON_FREQUENCY_FIELD_NUMBER: _ClassVar[int]
    COUPON_RATE_FIELD_NUMBER: _ClassVar[int]
    COUPON_TYPE_FIELD_NUMBER: _ClassVar[int]
    DATED_DATE_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    FACE_VALUE_FIELD_NUMBER: _ClassVar[int]
    IDENTIFIER_FIELD_NUMBER: _ClassVar[int]
    ISSUER_NAME_FIELD_NUMBER: _ClassVar[int]
    ISSUE_DATE_FIELD_NUMBER: _ClassVar[int]
    IS_LINK_FIELD_NUMBER: _ClassVar[int]
    MATURITY_DATE_FIELD_NUMBER: _ClassVar[int]
    OBJECT_CLASS_FIELD_NUMBER: _ClassVar[int]
    QUANTITY_TYPE_FIELD_NUMBER: _ClassVar[int]
    SECURITY_TYPE_FIELD_NUMBER: _ClassVar[int]
    SETTLEMENT_CURRENCY_FIELD_NUMBER: _ClassVar[int]
    UUID_FIELD_NUMBER: _ClassVar[int]
    VALID_FROM_FIELD_NUMBER: _ClassVar[int]
    VALID_TO_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    as_of: _local_timestamp_pb2.LocalTimestampProto
    asset_class: str
    cash_id: str
    coupon_frequency: _coupon_frequency_pb2.CouponFrequencyProto
    coupon_rate: _decimal_value_pb2.DecimalValueProto
    coupon_type: _coupon_type_pb2.CouponTypeProto
    dated_date: _local_date_pb2.LocalDateProto
    description: str
    face_value: _decimal_value_pb2.DecimalValueProto
    identifier: _identifier_pb2.IdentifierProto
    is_link: bool
    issue_date: _local_date_pb2.LocalDateProto
    issuer_name: str
    maturity_date: _local_date_pb2.LocalDateProto
    object_class: str
    quantity_type: _security_quantity_type_pb2.SecurityQuantityTypeProto
    security_type: _security_type_pb2.SecurityTypeProto
    settlement_currency: SecurityProto
    uuid: _uuid_pb2.UUIDProto
    valid_from: _local_timestamp_pb2.LocalTimestampProto
    valid_to: _local_timestamp_pb2.LocalTimestampProto
    version: str
    def __init__(self, object_class: _Optional[str] = ..., version: _Optional[str] = ..., uuid: _Optional[_Union[_uuid_pb2.UUIDProto, _Mapping]] = ..., as_of: _Optional[_Union[_local_timestamp_pb2.LocalTimestampProto, _Mapping]] = ..., is_link: bool = ..., valid_from: _Optional[_Union[_local_timestamp_pb2.LocalTimestampProto, _Mapping]] = ..., valid_to: _Optional[_Union[_local_timestamp_pb2.LocalTimestampProto, _Mapping]] = ..., security_type: _Optional[_Union[_security_type_pb2.SecurityTypeProto, str]] = ..., asset_class: _Optional[str] = ..., issuer_name: _Optional[str] = ..., settlement_currency: _Optional[_Union[SecurityProto, _Mapping]] = ..., quantity_type: _Optional[_Union[_security_quantity_type_pb2.SecurityQuantityTypeProto, str]] = ..., identifier: _Optional[_Union[_identifier_pb2.IdentifierProto, _Mapping]] = ..., description: _Optional[str] = ..., cash_id: _Optional[str] = ..., coupon_rate: _Optional[_Union[_decimal_value_pb2.DecimalValueProto, _Mapping]] = ..., coupon_type: _Optional[_Union[_coupon_type_pb2.CouponTypeProto, str]] = ..., coupon_frequency: _Optional[_Union[_coupon_frequency_pb2.CouponFrequencyProto, str]] = ..., dated_date: _Optional[_Union[_local_date_pb2.LocalDateProto, _Mapping]] = ..., face_value: _Optional[_Union[_decimal_value_pb2.DecimalValueProto, _Mapping]] = ..., issue_date: _Optional[_Union[_local_date_pb2.LocalDateProto, _Mapping]] = ..., maturity_date: _Optional[_Union[_local_date_pb2.LocalDateProto, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: fintekkers/models/util/endpoint.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%fintekkers/models/util/endpoint.proto\x12\x16\x66intekkers.models.util\"A\n\x08\x45ndpoint\x12\n\n\x02ip\x18\x01 \x01(\t\x12\x0c\n\x04port\x18\x02 \x01(\r\x12\x1b\n\x13\x66ully_qualified_url\x18\x03 \x01(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'fintekkers.models.util.endpoint_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ENDPOINT._serialized_start=65
  _ENDPOINT._serialized_end=130
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: fintekkers/models/util/local_date.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'fintekkers/models/util/local_date.proto\x12\x16\x66intekkers.models.util\":\n\x0eLocalDateProto\x12\x0c\n\x04year\x18\x01 \x01(\r\x12\r\n\x05month\x18\x02 \x01(\r\x12\x0b\n\x03\x64\x61y\x18\x03 \x01(\rb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'fintekkers.models.util.local_date_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _LOCALDATEPROTO._serialized_start=67
  _LOCALDATEPROTO._serialized_end=125
# @@protoc_insertion_point(module_scope)




from typing import Union
from fintekkers.models.position.field_pb2 import FieldProto
from fintekkers.models.position.position_status_pb2 import *
from fintekkers.models.portfolio.portfolio_pb2 import PortfolioProto
from fintekkers.models.security.identifier.identifier_pb2 import IdentifierProto
from fintekkers.models.security.security_pb2 import SecurityProto
from fintekkers.models.util.local_date_pb2 import LocalDateProto
from fintekkers.models.util.local_timestamp_pb2 import LocalTimestampProto
from fintekkers.models.util.uuid_pb2 import UUIDProto
from fintekkers.models.util.decimal_value_pb2 import DecimalValueProto

# from fintekkers.wrappers.models.position import Position
# from fintekkers.wrappers.models.security import Security
from fintekkers.wrappers.models.security_identifier import Identifier
from fintekkers.wrappers.models.transaction import TransactionType
from fintekkers.wrappers.models.util.fintekkers_uuid import FintekkersUuid

from google.protobuf.timestamp_pb2 import Timestamp
from datetime import date, datetime
import time
from pytz import timezone

from fintekkers.models.transaction.transaction_type_pb2 import TransactionTypeProto
from uuid import UUID, uuid4

from google._upb._message import EnumValueDescriptor

class ProtoEnum:
    def __init__(self, enum_descriptor:EnumValueDescriptor, enum_value:int):
        self.enum_value:int = enum_value
        self.get_enum_descriptor = enum_descriptor
        # Will be the proto
        self.enum:obj = ProtoEnum.get_field_descriptor(enum_descriptor) 


    @staticmethod 
    def from_enum_name(enum_name:str, enum_value:int):
        return ProtoEnum(ProtoEnum.get_field_descriptor_from_name(enum_name), enum_value)

    @staticmethod
    def get_field_descriptor(enum_descriptor:str):
        return ProtoEnum.get_field_descriptor_from_name(enum_descriptor.name)

    # @staticmethod
    # def get_field_descriptor_from_field_proto_id(field_id:str):
    #     if enum_name == "TRANSACTION_TYPE":
    #         return TransactionTypeProto
    #     if enum_name == "POSITION_STATUS":
    #         return PositionStatusProto
        
    #     raise ValueError(f"Enum has not been mapped: {enum_name}")

    @staticmethod
    def get_field_descriptor_from_name(enum_name:str):
        if enum_name == "TRANSACTION_TYPE":
            return TransactionTypeProto
        if enum_name == "POSITION_STATUS":
            return PositionStatusProto
        
        raise ValueError(f"Enum has not been mapped: {enum_name}")
    
        
    def get_enum_name(self) ->str:
        '''
        The string name of the enum
        '''
        return self.enum_descriptor.name
    
    def get_enum_value(self) -> int:
        ''' 
        Returns the numer of the enum value. Eg. zero generally means unknown,
        and 1 would be the first value in that enum. '''
        return self.enum_value
    
    def get_enum_value_name(self) -> str:
        '''
        Returns the string name of the enum, e.g. if the value is zero then
        this will generally be "UNKNOWN".
        '''
        return self.enum.DESCRIPTOR.values_by_number[self.enum_value].name

    def __str__(self) -> str:
        return self.get_enum_value_name()

class ProtoSerializationUtil:
    @staticmethod
    def serialize(obj):
        if isinstance(obj, UUID):
            return UUIDProto(raw_uuid=obj.bytes)
        if type(obj) is date:
            return LocalDateProto(year=obj.year, month=obj.month, day=obj.day)
        if isinstance(obj, datetime):
            seconds_in_float:float = time.mktime(obj.timetuple())
            timestamp = Timestamp(seconds=int(seconds_in_float), 
                nanos=int(obj.microsecond/1000))

            time_zone = obj.timetz().tzinfo.zone if obj.timetz().tzinfo is not None else "America/New_York"
            return LocalTimestampProto(timestamp=timestamp, time_zone=time_zone)
        if isinstance(obj, Identifier) or isinstance(obj, TransactionType):
            return obj.proto
        if isinstance(obj, float) or isinstance(obj, int):
            return DecimalValueProto(arbitrary_precision_value=str(obj))

        raise ValueError(f"Could not serialize object of type {obj.__class__.__name__}. Value: {obj}")
        

    @staticmethod
    def deserialize(obj):
        if isinstance(obj, UUIDProto):
            return FintekkersUuid.from_bytes(raw_uuid=obj.raw_uuid)
        if isinstance(obj, LocalDateProto):
            return date(year=obj.year, month=obj.month, day=obj.day)
        if isinstance(obj, LocalTimestampProto):
            return datetime.fromtimestamp(obj.timestamp.seconds, timezone(obj.time_zone))
        if isinstance(obj, IdentifierProto):
            return Identifier(obj)
        if isinstance(obj, DecimalValueProto):
            obj:DecimalValueProto
            return float(obj.arbitrary_precision_value)
        # if isinstance(obj, SecurityProto):
        #     obj:SecurityProto
        #     return Security(obj)
        # if isinstance(obj, PortfolioProto):
        #     obj:PortfolioProto
        #     return Position(obj)
        if hasattr(obj, 'enum_name') and getattr(obj, 'enum_name') == "TRANSACTION_TYPE":
            return TransactionType(obj.enum_value)

        raise ValueError(f"Could not deserialize object of type {obj.__class__.__name__}. Value: {obj}")

if __name__ == "__main__":
    serialized:UUIDProto = ProtoSerializationUtil.serialize(uuid4())
    assert isinstance(serialized, UUIDProto)
    deserialized:UUID = ProtoSerializationUtil.deserialize(serialized)
    assert isinstance(deserialized, UUID)

    serialized:LocalDateProto = ProtoSerializationUtil.serialize(date.today())
    assert isinstance(serialized, LocalDateProto)
    deserialized:date = ProtoSerializationUtil.deserialize(serialized)
    assert isinstance(deserialized, date)

    obj = datetime.today().replace(tzinfo=timezone("America/New_York"))
    serialized:LocalTimestampProto = ProtoSerializationUtil.serialize(obj)
    assert isinstance(serialized, LocalTimestampProto)
    deserialized:datetime = ProtoSerializationUtil.deserialize(serialized)
    assert isinstance(deserialized, datetime)



from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

ANNUALLY: CouponFrequencyProto
DESCRIPTOR: _descriptor.FileDescriptor
MONTHLY: CouponFrequencyProto
NO_COUPON: CouponFrequencyProto
QUARTERLY: CouponFrequencyProto
SEMIANNUALLY: CouponFrequencyProto
UNKNOWN_COUPON_FREQUENCY: CouponFrequencyProto

class CouponFrequencyProto(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []



from fintekkers.models.security import security_pb2 as _security_pb2
from fintekkers.models.position import position_pb2 as _position_pb2
from fintekkers.models.price import price_pb2 as _price_pb2
from fintekkers.requests.util import operation_pb2 as _operation_pb2
from fintekkers.models.position import measure_pb2 as _measure_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ValuationRequestProto(_message.Message):
    __slots__ = ["measures", "object_class", "operation_type", "position_input", "price_input", "security_input", "version"]
    MEASURES_FIELD_NUMBER: _ClassVar[int]
    OBJECT_CLASS_FIELD_NUMBER: _ClassVar[int]
    OPERATION_TYPE_FIELD_NUMBER: _ClassVar[int]
    POSITION_INPUT_FIELD_NUMBER: _ClassVar[int]
    PRICE_INPUT_FIELD_NUMBER: _ClassVar[int]
    SECURITY_INPUT_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    measures: _containers.RepeatedScalarFieldContainer[_measure_pb2.MeasureProto]
    object_class: str
    operation_type: _operation_pb2.RequestOperationTypeProto
    position_input: _position_pb2.PositionProto
    price_input: _price_pb2.PriceProto
    security_input: _security_pb2.SecurityProto
    version: str
    def __init__(self, object_class: _Optional[str] = ..., version: _Optional[str] = ..., operation_type: _Optional[_Union[_operation_pb2.RequestOperationTypeProto, str]] = ..., measures: _Optional[_Iterable[_Union[_measure_pb2.MeasureProto, str]]] = ..., security_input: _Optional[_Union[_security_pb2.SecurityProto, _Mapping]] = ..., position_input: _Optional[_Union[_position_pb2.PositionProto, _Mapping]] = ..., price_input: _Optional[_Union[_price_pb2.PriceProto, _Mapping]] = ...) -> None: ...
